@@ -1,7 +1,10 @@
-# $Id: renderer.py 245486 2011-10-13 13:51:23Z tom_gross $
+# $Id$
 
 from AccessControl import getSecurityManager, Unauthorized
-from Globals import DTMLFile
+try:
+    from App.special_dtml import DTMLFile
+except ImportError:
+    from Globals import DTMLFile
 from DateTime import DateTime
 
 from zope.interface import directlyProvides
@@ -103,7 +106,7 @@ class SimpleContainerRenderer(BrowserView):
 
 
 class WithPublishDateRenderer(SimpleContainerRenderer):
-    
+
     def getContents(self):
         show_inactive = _checkPermission(AccessInactivePortalContent, self)
         result = self.context.folderlistingFolderContents()
@@ -115,7 +118,7 @@ class WithPublishDateRenderer(SimpleContainerRenderer):
                     return item.get_target()
                 else:
                     return item
-                
+
             now = DateTime()
             result = [item for item in result if getItem(item).effective() < now < getItem(item).expires()]
         return result
